@@ -88,9 +88,6 @@ typedef struct {
   GtkWidget *param_account_widget;
   GtkWidget *param_password_widget;
 
-  gboolean automatic_change;
-  GtkWidget *remember_password_widget;
-
   /* Used only for IRC accounts */
   EmpathyIrcNetworkChooser *irc_network_chooser;
 
@@ -189,11 +186,6 @@ static void
 account_widget_entry_changed_cb (GtkEditable *entry,
     EmpathyAccountWidget *self)
 {
-  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
-
-  if (priv->automatic_change)
-    return;
-
   account_widget_entry_changed_common (self, GTK_ENTRY (entry), FALSE);
   empathy_account_widget_changed (self);
 }
@@ -766,10 +758,8 @@ account_widget_applied_cb (GObject *source_object,
   EmpathyAccountSettings *settings = EMPATHY_ACCOUNT_SETTINGS (source_object);
   EmpathyAccountWidget *widget = EMPATHY_ACCOUNT_WIDGET (user_data);
   EmpathyAccountWidgetPriv *priv = GET_PRIV (widget);
-  gboolean reconnect_required;
 
-  empathy_account_settings_apply_finish (settings, res, &reconnect_required,
-      &error);
+  empathy_account_settings_apply_finish (settings, res, &error);
 
   if (error != NULL)
     {
@@ -806,19 +796,10 @@ account_widget_applied_cb (GObject *source_object,
                 GTK_TOGGLE_BUTTON (priv->enabled_checkbox));
 #endif /* HAVE_MEEGO */
 
-          /* If the account was offline, we always want to try reconnecting,
-           * to give it a chance to connect if the previous params were wrong.
-           * tp_account_reconnect_async() won't do anything if the requested
-           * presence is offline anyway. */
-          if (tp_account_get_connection_status (account, NULL) ==
-              TP_CONNECTION_STATUS_DISCONNECTED)
-            reconnect_required = TRUE;
-
-          if (reconnect_required && tp_account_is_enabled (account)
-              && enabled_checked)
+          if (tp_account_is_enabled (account) && enabled_checked)
             {
               /* After having applied changes to a user account, we
-               * reconnect it if needed. This is done so the new
+               * automatically reconnect it. This is done so the new
                * information entered by the user is validated on the server. */
               tp_account_reconnect_async (account, NULL, NULL);
             }
@@ -986,17 +967,6 @@ account_widget_build_sip (EmpathyAccountWidget *self,
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   empathy_account_widget_sip_build (self, filename,
     &priv->table_common_settings);
-
-  if (priv->simple)
-    {
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
-    }
-  else
-    {
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
-    }
 }
 
 static void
@@ -1017,9 +987,6 @@ account_widget_build_msn (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1036,9 +1003,6 @@ account_widget_build_msn (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1165,9 +1129,6 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
     }
   else if (priv->simple && is_gtalk)
     {
@@ -1182,9 +1143,6 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_g_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_g_simple"));
     }
   else if (priv->simple && is_facebook)
     {
@@ -1201,9 +1159,6 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
       setup_facebook_id_widget (self, entry_id);
 
       self->ui_details->default_focus = g_strdup ("entry_id_fb_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_fb_simple"));
     }
   else
     {
@@ -1248,9 +1203,6 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
       self->ui_details->default_focus = g_strdup ("entry_id");
       priv->spinbutton_port = spinbutton_port;
 
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
-
       g_signal_connect (checkbutton_ssl, "toggled",
           G_CALLBACK (account_widget_jabber_ssl_toggled_cb),
           self);
@@ -1288,9 +1240,6 @@ account_widget_build_icq (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_uin_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1309,9 +1258,6 @@ account_widget_build_icq (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_uin");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1334,9 +1280,6 @@ account_widget_build_aim (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_screenname_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1354,9 +1297,6 @@ account_widget_build_aim (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_screenname");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1378,9 +1318,6 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1392,6 +1329,7 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
       empathy_account_widget_handle_params (self,
           "entry_id", "account",
           "entry_password", "password",
+          "entry_server", "server",
           "entry_locale", "room-list-locale",
           "entry_charset", "charset",
           "spinbutton_port", "port",
@@ -1399,9 +1337,6 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1423,9 +1358,6 @@ account_widget_build_groupwise (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1442,9 +1374,6 @@ account_widget_build_groupwise (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id");
-
-      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
-              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1481,7 +1410,6 @@ empathy_account_widget_enabled_cb (TpAccount *account,
     }
 }
 
-#if 0
 static void
 #ifdef HAVE_MEEGO
 account_widget_switch_flipped_cb (MxGtkLightSwitch *sw,
@@ -1508,7 +1436,6 @@ account_widget_enabled_toggled_cb (GtkToggleButton *toggle_button,
   tp_account_set_enabled_async (account, state,
       account_widget_account_enabled_cb, user_data);
 }
-#endif
 
 void
 empathy_account_widget_set_other_accounts_exist (EmpathyAccountWidget *self,
@@ -1671,7 +1598,6 @@ static void
 add_enable_checkbox (EmpathyAccountWidget *self,
     TpAccount *account)
 {
-#if 0
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
 #ifdef HAVE_MEEGO
   GtkWidget *w;
@@ -1734,7 +1660,6 @@ add_enable_checkbox (EmpathyAccountWidget *self,
   g_signal_connect (G_OBJECT (priv->enabled_checkbox), "toggled",
       G_CALLBACK (account_widget_enabled_toggled_cb), self);
 #endif /* HAVE_MEEGO */
-#endif
 }
 
 #ifndef HAVE_MEEGO
@@ -1779,48 +1704,6 @@ add_register_buttons (EmpathyAccountWidget *self,
 }
 #endif /* HAVE_MEEGO */
 
-static void
-remember_password_toggled_cb (GtkToggleButton *button,
-    EmpathyAccountWidget *self)
-{
-  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
-
-  if (gtk_toggle_button_get_active (button))
-    {
-      gtk_widget_set_sensitive (priv->param_password_widget, TRUE);
-    }
-  else
-    {
-      gtk_widget_set_sensitive (priv->param_password_widget, FALSE);
-      gtk_entry_set_text (GTK_ENTRY (priv->param_password_widget), "");
-      empathy_account_settings_unset (priv->settings, "password");
-    }
-}
-
-static void
-account_settings_password_retrieved_cb (GObject *object,
-    gpointer user_data)
-{
-  EmpathyAccountWidget *self = user_data;
-  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
-  const gchar *password = empathy_account_settings_get_string (
-      priv->settings, "password");
-
-  if (password != NULL)
-    {
-      /* We have to do this so that when we call gtk_entry_set_text,
-       * the ::changed callback doesn't think the user made the
-       * change. */
-      priv->automatic_change = TRUE;
-      gtk_entry_set_text (GTK_ENTRY (priv->param_password_widget), password);
-      priv->automatic_change = FALSE;
-    }
-
-  gtk_toggle_button_set_active (
-      GTK_TOGGLE_BUTTON (priv->remember_password_widget),
-      !EMP_STR_EMPTY (password));
-}
-
 static void
 do_constructed (GObject *obj)
 {
@@ -1887,42 +1770,6 @@ do_constructed (GObject *obj)
           NULL);
     }
 
-  /* remember password */
-  if (priv->param_password_widget != NULL
-      && priv->remember_password_widget != NULL
-      && empathy_account_settings_supports_sasl (priv->settings))
-    {
-      if (priv->simple)
-        {
-          gtk_toggle_button_set_active (
-              GTK_TOGGLE_BUTTON (priv->remember_password_widget), TRUE);
-        }
-      else
-        {
-          gtk_toggle_button_set_active (
-              GTK_TOGGLE_BUTTON (priv->remember_password_widget),
-              !EMP_STR_EMPTY (empathy_account_settings_get_string (
-                      priv->settings, "password")));
-
-          /* The password might not have been retrieved from the
-           * keyring yet. We should update the remember password
-           * toggle button and the password entry when/if it is. */
-          g_signal_connect (priv->settings, "password-retrieved",
-              G_CALLBACK (account_settings_password_retrieved_cb), self);
-        }
-
-      g_signal_connect (priv->remember_password_widget, "toggled",
-          G_CALLBACK (remember_password_toggled_cb), self);
-
-      remember_password_toggled_cb (
-          GTK_TOGGLE_BUTTON (priv->remember_password_widget), self);
-    }
-  else if (priv->remember_password_widget != NULL
-      && !empathy_account_settings_supports_sasl (priv->settings))
-    {
-      gtk_widget_set_visible (priv->remember_password_widget, FALSE);
-    }
-
   /* dup and init the account-manager */
   priv->account_manager = tp_account_manager_dup ();
 
