@@ -42,7 +42,6 @@
 #include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
-#include <libempathy/empathy-marshal.h>
 
 #include "empathy-chat.h"
 #include "empathy-spell.h"
@@ -58,7 +57,6 @@
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
 #include <libempathy/empathy-debug.h>
 
-
 #define CHAT_DIR_CREATE_MODE  (S_IRUSR | S_IWUSR | S_IXUSR)
 #define CHAT_FILE_CREATE_MODE (S_IRUSR | S_IWUSR)
 #define IS_ENTER(v) (v == GDK_KEY_Return || v == GDK_KEY_ISO_Enter || v == GDK_KEY_KP_Enter)
@@ -1110,9 +1108,7 @@ chat_state_changed_cb (EmpathyTpChat      *tp_chat,
 }
 
 static void
-chat_message_received (EmpathyChat *chat,
-	EmpathyMessage *message,
-	gboolean pending)
+chat_message_received (EmpathyChat *chat, EmpathyMessage *message)
 {
 	EmpathyChatPriv *priv = GET_PRIV (chat);
 	EmpathyContact  *sender;
@@ -1131,7 +1127,7 @@ chat_message_received (EmpathyChat *chat,
 			       chat);
 
 	priv->unread_messages++;
-	g_signal_emit (chat, signals[NEW_MESSAGE], 0, message, pending);
+	g_signal_emit (chat, signals[NEW_MESSAGE], 0, message);
 }
 
 static void
@@ -1139,7 +1135,7 @@ chat_message_received_cb (EmpathyTpChat  *tp_chat,
 			  EmpathyMessage *message,
 			  EmpathyChat    *chat)
 {
-	chat_message_received (chat, message, FALSE);
+	chat_message_received (chat, message);
 }
 
 static void
@@ -1897,7 +1893,7 @@ chat_input_populate_popup_cb (GtkTextView *view,
 
 
 static gboolean
-chat_log_filter (TplEvent *log,
+chat_log_filter (TplEntry *log,
 		 gpointer user_data)
 {
 	EmpathyChat *chat = user_data;
@@ -1905,15 +1901,14 @@ chat_log_filter (TplEvent *log,
 	EmpathyChatPriv *priv = GET_PRIV (chat);
 	const GList *pending;
 
-	g_return_val_if_fail (TPL_IS_EVENT (log), FALSE);
+	g_return_val_if_fail (TPL_IS_ENTRY (log), FALSE);
 	g_return_val_if_fail (EMPATHY_IS_CHAT (chat), FALSE);
 
 	pending = empathy_tp_chat_get_pending_messages (priv->tp_chat);
-	message = empathy_message_from_tpl_log_event (log);
+	message = empathy_message_from_tpl_log_entry (log);
 
 	for (; pending; pending = g_list_next (pending)) {
 		if (empathy_message_equal (message, pending->data)) {
-			g_object_unref (message);
 			return FALSE;
 		}
 	}
@@ -1940,7 +1935,7 @@ show_pending_messages (EmpathyChat *chat) {
 
 	for (l = messages; l != NULL ; l = g_list_next (l)) {
 		EmpathyMessage *message = EMPATHY_MESSAGE (l->data);
-		chat_message_received (chat, message, TRUE);
+		chat_message_received (chat, message);
 	}
 }
 
@@ -1956,7 +1951,7 @@ got_filtered_messages_cb (GObject *manager,
 	EmpathyChatPriv *priv = GET_PRIV (chat);
 	GError *error = NULL;
 
-	if (!tpl_log_manager_get_filtered_events_finish (TPL_LOG_MANAGER (manager),
+	if (!tpl_log_manager_get_filtered_messages_finish (TPL_LOG_MANAGER (manager),
 		result, &messages, &error)) {
 		DEBUG ("%s. Aborting.", error->message);
 		empathy_chat_view_append_event (chat->view,
@@ -1967,9 +1962,9 @@ got_filtered_messages_cb (GObject *manager,
 
 	for (l = messages; l; l = g_list_next (l)) {
 		EmpathyMessage *message;
-		g_assert (TPL_IS_EVENT (l->data));
+		g_assert (TPL_IS_ENTRY (l->data));
 
-		message = empathy_message_from_tpl_log_event (l->data);
+		message = empathy_message_from_tpl_log_entry (l->data);
 		g_object_unref (l->data);
 
 		empathy_chat_view_append_message (chat->view, message);
@@ -1995,7 +1990,7 @@ static void
 chat_add_logs (EmpathyChat *chat)
 {
 	EmpathyChatPriv *priv = GET_PRIV (chat);
-	TplEntity       *target;
+	gboolean         is_chatroom;
 
 	if (!priv->id) {
 		return;
@@ -2005,23 +2000,18 @@ chat_add_logs (EmpathyChat *chat)
 	empathy_chat_view_scroll (chat->view, FALSE);
 
 	/* Add messages from last conversation */
-	if (priv->handle_type == TP_HANDLE_TYPE_ROOM)
-	  target = tpl_entity_new_from_room_id (priv->id);
-	else
-	  target = tpl_entity_new (priv->id, TPL_ENTITY_CONTACT, NULL, NULL);
+	is_chatroom = priv->handle_type == TP_HANDLE_TYPE_ROOM;
 
 	priv->retrieving_backlogs = TRUE;
-	tpl_log_manager_get_filtered_events_async (priv->log_manager,
-						   priv->account,
-						   target,
-						   TPL_EVENT_MASK_TEXT,
-						   5,
-						   chat_log_filter,
-						   chat,
-						   got_filtered_messages_cb,
-						   (gpointer) chat);
-
-	g_object_unref (target);
+	tpl_log_manager_get_filtered_messages_async (priv->log_manager,
+							      priv->account,
+							      priv->id,
+							      is_chatroom,
+							      5,
+							      chat_log_filter,
+							      chat,
+							      got_filtered_messages_cb,
+							      (gpointer) chat);
 }
 
 static gint
@@ -2431,7 +2421,6 @@ chat_create_ui (EmpathyChat *chat)
 	gchar           *filename;
 	GtkTextBuffer   *buffer;
 	gint              paned_pos;
-	EmpathyThemeManager *theme_mgr;
 
 	filename = empathy_file_lookup ("empathy-chat.ui",
 					"libempathy-gtk");
@@ -2457,9 +2446,7 @@ chat_create_ui (EmpathyChat *chat)
 	g_free (filename);
 
 	/* Add message view. */
-	theme_mgr = empathy_theme_manager_dup_singleton ();
-	chat->view = empathy_theme_manager_create_view (theme_mgr);
-	g_object_unref (theme_mgr);
+	chat->view = empathy_theme_manager_create_view (empathy_theme_manager_get ());
 	/* If this is a GtkTextView, it's set as a drag destination for text/plain
 	   and other types, even though it's non-editable and doesn't accept any
 	   drags.  This steals drag motion for anything inside the scrollbars,
@@ -2548,29 +2535,6 @@ chat_create_ui (EmpathyChat *chat)
 	g_object_unref (gui);
 }
 
-static void
-chat_size_request (GtkWidget      *widget,
-		   GtkRequisition *requisition)
-{
-  GtkBin *bin = GTK_BIN (widget);
-  GtkWidget *child;
-
-  requisition->width = gtk_container_get_border_width (GTK_CONTAINER (widget)) * 2;
-  requisition->height = gtk_container_get_border_width (GTK_CONTAINER (widget)) * 2;
-
-  child = gtk_bin_get_child (bin);
-
-  if (child && gtk_widget_get_visible (child))
-    {
-      GtkRequisition child_requisition;
-
-      gtk_widget_size_request (child, &child_requisition);
-
-      requisition->width += child_requisition.width;
-      requisition->height += child_requisition.height;
-    }
-}
-
 static void
 chat_size_allocate (GtkWidget     *widget,
 		    GtkAllocation *allocation)
@@ -2687,7 +2651,6 @@ empathy_chat_class_init (EmpathyChatClass *klass)
 	object_class->set_property = chat_set_property;
 	object_class->constructed = chat_constructed;
 
-	widget_class->size_request = chat_size_request;
 	widget_class->size_allocate = chat_size_allocate;
 
 	g_object_class_install_property (object_class,
@@ -2764,9 +2727,9 @@ empathy_chat_class_init (EmpathyChatClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      _empathy_marshal_VOID__OBJECT_BOOLEAN,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
-			      2, EMPATHY_TYPE_MESSAGE, G_TYPE_BOOLEAN);
+			      1, EMPATHY_TYPE_MESSAGE);
 
 	g_type_class_add_private (object_class, sizeof (EmpathyChatPriv));
 }
@@ -3179,8 +3142,7 @@ empathy_chat_get_contact_menu (EmpathyChat *chat)
 		menu = empathy_contact_menu_new (priv->remote_contact,
 						 EMPATHY_CONTACT_FEATURE_CALL |
 						 EMPATHY_CONTACT_FEATURE_LOG |
-						 EMPATHY_CONTACT_FEATURE_INFO |
-						 EMPATHY_CONTACT_FEATURE_BLOCK);
+						 EMPATHY_CONTACT_FEATURE_INFO);
 	}
 	else if (priv->contact_list_view) {
 		EmpathyContactListView *view;
