@@ -31,6 +31,7 @@
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
 
+#include <libempathy/empathy-call-factory.h>
 #include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-individual-manager.h>
 #include <libempathy/empathy-chatroom-manager.h>
@@ -46,7 +47,6 @@
 #include "empathy-ui-utils.h"
 #include "empathy-share-my-desktop.h"
 #include "empathy-linking-dialog.h"
-#include "empathy-call-utils.h"
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyIndividualMenu)
 
@@ -88,7 +88,7 @@ individual_menu_add_personas (GtkMenuShell *menu,
    * functionality */
   for (l = personas; l != NULL; l = l->next)
     {
-      if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+      if (!TPF_IS_PERSONA (l->data))
         continue;
 
       persona_count++;
@@ -117,7 +117,7 @@ individual_menu_add_personas (GtkMenuShell *menu,
       const gchar *account;
       GtkWidget *action;
 
-      if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+      if (!TPF_IS_PERSONA (persona))
         continue;
 
       tp_contact = tpf_persona_get_contact (persona);
@@ -460,10 +460,8 @@ menu_item_set_contact (GtkWidget *item,
 
   if (can_do_action == TRUE)
     {
-      /* We want to make sure that the EmpathyContact stays alive while the
-       * signal is connected. */
-      g_signal_connect_data (item, "activate", G_CALLBACK (activate_callback),
-          g_object_ref (contact), (GClosureNotify) g_object_unref, 0);
+      g_signal_connect (item, "activate", G_CALLBACK (activate_callback),
+          contact);
     }
 
   return can_do_action;
@@ -543,10 +541,8 @@ empathy_individual_audio_call_menu_item_activated (GtkMenuItem *item,
 {
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
-  empathy_call_new_with_streams (empathy_contact_get_id (contact),
-      empathy_contact_get_account (contact),
-      TRUE, FALSE,
-      gtk_get_current_event_time ());
+  empathy_call_factory_new_call_with_streams (contact, TRUE, FALSE,
+      gtk_get_current_event_time (), NULL);
 }
 
 GtkWidget *
@@ -587,10 +583,8 @@ empathy_individual_video_call_menu_item_activated (GtkMenuItem *item,
 {
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
-  empathy_call_new_with_streams (empathy_contact_get_id (contact),
-      empathy_contact_get_account (contact),
-      TRUE, TRUE,
-      gtk_get_current_event_time ());
+  empathy_call_factory_new_call_with_streams (contact, TRUE, TRUE,
+      gtk_get_current_event_time (), NULL);
 }
 
 GtkWidget *
@@ -755,7 +749,7 @@ static void
 favourite_menu_item_toggled_cb (GtkCheckMenuItem *item,
   FolksIndividual *individual)
 {
-  folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual),
+  folks_favourite_set_is_favourite (FOLKS_FAVOURITE (individual),
       gtk_check_menu_item_get_active (item));
 }
 
@@ -767,7 +761,7 @@ empathy_individual_favourite_menu_item_new (FolksIndividual *individual)
   item = gtk_check_menu_item_new_with_label (_("Favorite"));
 
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-      folks_favouritable_get_is_favourite (FOLKS_FAVOURITABLE (individual)));
+      folks_favourite_get_is_favourite (FOLKS_FAVOURITE (individual)));
 
   g_signal_connect (item, "toggled",
       G_CALLBACK (favourite_menu_item_toggled_cb), individual);
@@ -945,7 +939,7 @@ room_sub_menu_activate_cb (GtkWidget *item,
           TpContact *tp_contact;
           GList *rooms;
 
-          if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+          if (!TPF_IS_PERSONA (persona))
             continue;
 
           tp_contact = tpf_persona_get_contact (persona);
@@ -1045,7 +1039,7 @@ empathy_individual_invite_menu_item_new (FolksIndividual *individual,
           TpContact *tp_contact;
           EmpathyContact *contact_cur;
 
-          if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+          if (!TPF_IS_PERSONA (persona))
             continue;
 
           tp_contact = tpf_persona_get_contact (persona);
