@@ -48,6 +48,7 @@
 #include "empathy-individual-menu.h"
 #include "empathy-individual-store.h"
 #include "empathy-images.h"
+#include "empathy-linking-dialog.h"
 #include "empathy-cell-renderer-expander.h"
 #include "empathy-cell-renderer-text.h"
 #include "empathy-cell-renderer-activatable.h"
@@ -881,7 +882,7 @@ individual_view_key_press_event_cb (EmpathyIndividualView *view,
     GdkEventKey *event,
     gpointer user_data)
 {
-  if (event->keyval == GDK_Menu)
+  if (event->keyval == GDK_KEY_Menu)
     {
       MenuPopupData *data;
 
@@ -902,11 +903,9 @@ individual_view_row_activated (GtkTreeView *view,
 {
   EmpathyIndividualViewPriv *priv = GET_PRIV (view);
   FolksIndividual *individual;
-  EmpathyContact *contact = NULL;
-  FolksPresenceType best_presence = FOLKS_PRESENCE_TYPE_UNSET;
+  EmpathyContact *contact;
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GList *personas, *l;
 
   if (!(priv->individual_features & EMPATHY_INDIVIDUAL_FEATURE_CHAT))
     return;
@@ -920,29 +919,8 @@ individual_view_row_activated (GtkTreeView *view,
     return;
 
   /* Determine which Persona to chat to, by choosing the most available one. */
-  personas = folks_individual_get_personas (individual);
-  for (l = personas; l != NULL; l = l->next)
-    {
-      FolksPresenceType presence;
-
-      if (!TPF_IS_PERSONA (l->data))
-        continue;
-
-      /* Only choose the contact if it has a higher presence than our current
-       * best choice of contact. */
-      presence = folks_presence_get_presence_type (FOLKS_PRESENCE (l->data));
-      if (folks_presence_typecmp (presence, best_presence) > 0)
-        {
-          TpContact *tp_contact;
-
-          tp_clear_object (&contact);
-          tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
-          contact = empathy_contact_dup_from_tp_contact (tp_contact);
-          empathy_contact_set_persona (contact, FOLKS_PERSONA (l->data));
-
-          best_presence = presence;
-        }
-    }
+  contact = empathy_contact_dup_best_for_action (individual,
+      EMPATHY_ACTION_CHAT);
 
   if (contact != NULL)
     {
@@ -1336,7 +1314,7 @@ individual_view_search_key_navigation_cb (GtkWidget *search,
   GdkEventKey *eventkey = ((GdkEventKey *) event);
   gboolean ret = FALSE;
 
-  if (eventkey->keyval == GDK_Up || eventkey->keyval == GDK_Down)
+  if (eventkey->keyval == GDK_KEY_Up || eventkey->keyval == GDK_KEY_Down)
     {
       GdkEvent *new_event;
 
@@ -1503,13 +1481,12 @@ individual_view_expand_idle_cb (EmpathyIndividualView *self)
   g_signal_handlers_unblock_by_func (self,
       individual_view_row_expand_or_collapse_cb, GINT_TO_POINTER (TRUE));
 
-  priv->expand_groups_idle_handler = 0;
-  g_object_unref (self);
-
   /* Empty the table of groups to expand/contract, since it may contain groups
    * which no longer exist in the tree view. This can happen after going
    * offline, for example. */
   g_hash_table_remove_all (priv->expand_groups);
+  priv->expand_groups_idle_handler = 0;
+  g_object_unref (self);
 
   return FALSE;
 }
@@ -2357,6 +2334,19 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
     }
 }
 
+static void
+individual_menu_link_contacts_activated_cb (EmpathyIndividualMenu *menu,
+    EmpathyLinkingDialog *linking_dialog,
+    EmpathyIndividualView *self)
+{
+  EmpathyIndividualViewPriv *priv = GET_PRIV (self);
+  EmpathyIndividualLinker *linker;
+
+  linker = empathy_linking_dialog_get_individual_linker (linking_dialog);
+  empathy_individual_linker_set_search_text (linker,
+      empathy_live_search_get_text (EMPATHY_LIVE_SEARCH (priv->search_widget)));
+}
+
 GtkWidget *
 empathy_individual_view_get_individual_menu (EmpathyIndividualView *view)
 {
@@ -2404,6 +2394,12 @@ empathy_individual_view_get_individual_menu (EmpathyIndividualView *view)
           G_CALLBACK (individual_view_remove_activate_cb), view);
     }
 
+  /* Connect to EmpathyIndividualMenu::link-contacts-activated so that we can
+   * set the live search text on the new linking dialogue to be the same as
+   * our own. */
+  g_signal_connect (menu, "link-contacts-activated",
+      (GCallback) individual_menu_link_contacts_activated_cb, view);
+
   g_object_unref (individual);
 
   return menu;
