@@ -45,7 +45,6 @@
 #include "empathy-groups-widget.h"
 #include "empathy-gtk-enum-types.h"
 #include "empathy-individual-widget.h"
-#include "empathy-kludge-label.h"
 #include "empathy-string-parser.h"
 #include "empathy-ui-utils.h"
 
@@ -400,7 +399,7 @@ details_update (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+          if (TPF_IS_PERSONA (l->data))
             {
               tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
               if (tp_contact != NULL)
@@ -437,7 +436,7 @@ groups_update (EmpathyIndividualWidget *self)
     {
       empathy_groups_widget_set_groupable (
           EMPATHY_GROUPS_WIDGET (priv->groups_widget),
-          FOLKS_GROUPABLE (priv->individual));
+          FOLKS_GROUPS (priv->individual));
       gtk_widget_show (priv->groups_widget);
     }
   else
@@ -548,7 +547,7 @@ location_update (EmpathyIndividualWidget *self)
     {
       FolksPersona *persona = FOLKS_PERSONA (l->data);
 
-      if (empathy_folks_persona_is_interesting (persona))
+      if (TPF_IS_PERSONA (persona))
         {
           TpContact *tp_contact;
 
@@ -721,7 +720,7 @@ location_update (EmpathyIndividualWidget *self)
         {
           FolksPersona *persona = FOLKS_PERSONA (l->data);
 
-          if (empathy_folks_persona_is_interesting (persona))
+          if (TPF_IS_PERSONA (persona))
             {
               gdouble lat = 0.0, lon = 0.0;
               ClutterActor *marker;
@@ -761,8 +760,8 @@ location_update (EmpathyIndividualWidget *self)
 
               /* Add a marker to the map */
               marker = champlain_marker_new_with_text (
-                  folks_aliasable_get_alias (FOLKS_ALIASABLE (persona)), NULL,
-                  NULL, NULL);
+                  folks_alias_get_alias (FOLKS_ALIAS (persona)), NULL, NULL,
+                  NULL);
               champlain_base_marker_set_position (
                   CHAMPLAIN_BASE_MARKER (marker), lat, lon);
               clutter_container_add (CLUTTER_CONTAINER (layer), marker, NULL);
@@ -793,7 +792,7 @@ persona_dup_avatar (FolksPersona *persona)
   EmpathyContact *contact;
   EmpathyAvatar *avatar;
 
-  if (!empathy_folks_persona_is_interesting (persona))
+  if (!TPF_IS_PERSONA (persona))
     return NULL;
 
   tp_contact = tpf_persona_get_contact (TPF_PERSONA (persona));
@@ -816,7 +815,7 @@ individual_dup_avatar (FolksIndividual *individual)
 
   /* FIXME: We just choose the first Persona which has an avatar, and save that.
    * The avatar handling in EmpathyContact needs to be moved into libfolks as
-   * much as possible, and this code rewritten to use FolksHasAvatar.
+   * much as possible, and this code rewritten to use FolksAvatar.
    * (bgo#627401) */
   personas = folks_individual_get_personas (individual);
   for (l = personas; l != NULL; l = l->next)
@@ -996,7 +995,7 @@ individual_is_user (FolksIndividual *individual)
     {
       FolksPersona *persona = FOLKS_PERSONA (l->data);
 
-      if (empathy_folks_persona_is_interesting (persona))
+      if (TPF_IS_PERSONA (persona))
         {
           TpContact *tp_contact;
           EmpathyContact *contact;
@@ -1058,7 +1057,7 @@ entry_alias_focus_event_cb (GtkEditable *editable,
         }
       else
         {
-          folks_aliasable_set_alias (FOLKS_ALIASABLE (priv->individual), alias);
+          folks_alias_set_alias (FOLKS_ALIAS (priv->individual), alias);
         }
     }
 
@@ -1070,8 +1069,8 @@ favourite_toggled_cb (GtkToggleButton *button,
     EmpathyIndividualWidget *self)
 {
   gboolean active = gtk_toggle_button_get_active (button);
-  folks_favouritable_set_is_favourite (
-      FOLKS_FAVOURITABLE (GET_PRIV (self)->individual), active);
+  folks_favourite_set_is_favourite (
+      FOLKS_FAVOURITE (GET_PRIV (self)->individual), active);
 }
 
 static void
@@ -1133,12 +1132,12 @@ notify_alias_cb (gpointer folks_object,
   if (GTK_IS_ENTRY (alias_widget))
     {
       gtk_entry_set_text (GTK_ENTRY (alias_widget),
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (folks_object)));
+          folks_alias_get_alias (FOLKS_ALIAS (folks_object)));
     }
   else
     {
       gtk_label_set_label (GTK_LABEL (alias_widget),
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (folks_object)));
+          folks_alias_get_alias (FOLKS_ALIAS (folks_object)));
     }
 }
 
@@ -1167,13 +1166,11 @@ notify_presence_cb (gpointer folks_object,
   state_image = g_object_get_data (table, "state-image");
 
   /* FIXME: Default messages should be moved into libfolks (bgo#627403) */
-  message = folks_presence_owner_get_presence_message (
-      FOLKS_PRESENCE_OWNER (folks_object));
+  message = folks_presence_get_presence_message (FOLKS_PRESENCE (folks_object));
   if (EMP_STR_EMPTY (message))
     {
       message = empathy_presence_get_default_message (
-          folks_presence_owner_get_presence_type (
-              FOLKS_PRESENCE_OWNER (folks_object)));
+          folks_presence_get_presence_type (FOLKS_PRESENCE (folks_object)));
     }
 
   if (message != NULL)
@@ -1183,8 +1180,7 @@ notify_presence_cb (gpointer folks_object,
 
   gtk_image_set_from_icon_name (GTK_IMAGE (state_image),
       empathy_icon_name_for_presence (
-          folks_presence_owner_get_presence_type (
-              FOLKS_PRESENCE_OWNER (folks_object))),
+          folks_presence_get_presence_type (FOLKS_PRESENCE (folks_object))),
       GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (state_image);
 }
@@ -1213,8 +1209,7 @@ notify_is_favourite_cb (gpointer folks_object,
   if (GTK_IS_TOGGLE_BUTTON (favourite_widget))
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (favourite_widget),
-          folks_favouritable_get_is_favourite (
-              FOLKS_FAVOURITABLE (folks_object)));
+          folks_favourite_get_is_favourite (FOLKS_FAVOURITE (folks_object)));
     }
 }
 
@@ -1271,8 +1266,7 @@ alias_presence_avatar_favourite_set_up (EmpathyIndividualWidget *self,
       FALSE, 0);
   gtk_widget_show (image);
 
-  /* Set up status_label as a KludgeLabel */
-  label = empathy_kludge_label_new ("");
+  label = gtk_label_new ("");
   gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD_CHAR);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
@@ -1391,7 +1385,7 @@ add_persona (EmpathyIndividualWidget *self,
   GtkWidget *label, *account_label, *account_image, *separator;
   guint current_row = 0;
 
-  if (!empathy_folks_persona_is_interesting (persona))
+  if (!TPF_IS_PERSONA (persona))
     return;
 
   if (priv->flags & EMPATHY_INDIVIDUAL_WIDGET_EDIT_FAVOURITE)
@@ -1494,7 +1488,7 @@ remove_persona (EmpathyIndividualWidget *self,
   GtkWidget *separator;
   GtkTable *table;
 
-  if (!empathy_folks_persona_is_interesting (persona))
+  if (!TPF_IS_PERSONA (persona))
     return;
 
   table = g_hash_table_lookup (priv->persona_tables, persona);
@@ -1566,7 +1560,7 @@ individual_table_set_up (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+          if (TPF_IS_PERSONA (l->data))
             num_personas++;
         }
 
@@ -1629,7 +1623,7 @@ personas_changed_cb (FolksIndividual *individual,
 
   for (l = personas; l != NULL; l = l->next)
     {
-      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+      if (TPF_IS_PERSONA (l->data))
         new_num_personas++;
     }
 
@@ -1811,7 +1805,7 @@ individual_update (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          if (!empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+          if (!TPF_IS_PERSONA (l->data))
             continue;
 
           update_persona (self, FOLKS_PERSONA (l->data));
