@@ -116,8 +116,8 @@ typedef struct {
 static GList *chat_windows = NULL;
 
 static const guint tab_accel_keys[] = {
-	GDK_1, GDK_2, GDK_3, GDK_4, GDK_5,
-	GDK_6, GDK_7, GDK_8, GDK_9, GDK_0
+	GDK_KEY_1, GDK_KEY_2, GDK_KEY_3, GDK_KEY_4, GDK_KEY_5,
+	GDK_KEY_6, GDK_KEY_7, GDK_KEY_8, GDK_KEY_9, GDK_KEY_0
 };
 
 typedef enum {
@@ -146,6 +146,20 @@ static const GtkTargetEntry drag_types_dest_file[] = {
 
 static void chat_window_update (EmpathyChatWindow *window);
 
+static void empathy_chat_window_add_chat (EmpathyChatWindow *window,
+			      EmpathyChat	*chat);
+
+static void empathy_chat_window_remove_chat (EmpathyChatWindow *window,
+				 EmpathyChat	   *chat);
+
+static void empathy_chat_window_move_chat (EmpathyChatWindow *old_window,
+			       EmpathyChatWindow *new_window,
+			       EmpathyChat       *chat);
+
+static void empathy_chat_window_get_nb_chats (EmpathyChatWindow *self,
+			       guint *nb_rooms,
+			       guint *nb_private);
+
 G_DEFINE_TYPE (EmpathyChatWindow, empathy_chat_window, G_TYPE_OBJECT);
 
 static void
@@ -403,10 +417,6 @@ chat_window_contact_menu_update (EmpathyChatWindowPriv *priv,
 
 	if (orig_submenu == NULL || !gtk_widget_get_visible (orig_submenu)) {
 		submenu = empathy_chat_get_contact_menu (priv->current_chat);
-
-		/* gtk_menu_attach_to_widget () doesn't behave nicely here */
-		g_object_set_data (G_OBJECT (submenu), "window", priv->dialog);
-
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu), submenu);
 		gtk_widget_show (menu);
 	} else {
@@ -1158,6 +1168,12 @@ chat_window_tabs_right_activate_cb (GtkAction         *action,
 	chat_window_menu_context_update (priv, num_pages);
 }
 
+static EmpathyChatWindow *
+empathy_chat_window_new (void)
+{
+	return EMPATHY_CHAT_WINDOW (g_object_new (EMPATHY_TYPE_CHAT_WINDOW, NULL));
+}
+
 static void
 chat_window_detach_activate_cb (GtkAction         *action,
 				EmpathyChatWindow *window)
@@ -1304,7 +1320,7 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 		   to an existing notification with the same title.
 		   In this way the previous message will not be lost: the new
 		   message will appear below it, in the same notification */
-		notification = notify_notification_new (header, escaped, NULL);
+		notification = notify_notification_new (header, escaped, NULL, NULL);
 
 		if (priv->notification == NULL) {
 			priv->notification = notification;
@@ -1352,10 +1368,24 @@ chat_window_set_highlight_room_tab_label (EmpathyChat *chat)
 	g_free (markup);
 }
 
+static gboolean
+empathy_chat_window_has_focus (EmpathyChatWindow *window)
+{
+	EmpathyChatWindowPriv *priv;
+	gboolean              has_focus;
+
+	g_return_val_if_fail (EMPATHY_IS_CHAT_WINDOW (window), FALSE);
+
+	priv = GET_PRIV (window);
+
+	g_object_get (priv->dialog, "has-toplevel-focus", &has_focus, NULL);
+
+	return has_focus;
+}
+
 static void
 chat_window_new_message_cb (EmpathyChat       *chat,
 			    EmpathyMessage    *message,
-			    gboolean pending,
 			    EmpathyChatWindow *window)
 {
 	EmpathyChatWindowPriv *priv;
@@ -1430,11 +1460,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 
 		empathy_sound_play (GTK_WIDGET (priv->dialog),
 		    EMPATHY_SOUND_MESSAGE_INCOMING);
-
-		/* Pending messages have already been displayed in the approver, so we don't
-		* display a notification for those. */
-		if (!pending)
-			chat_window_show_or_update_notification (window, message, chat);
+		chat_window_show_or_update_notification (window, message, chat);
 	}
 
 	/* update the number of unread messages and the window icon */
@@ -1443,7 +1469,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 }
 
 static GtkNotebook *
-chat_window_detach_hook (GtkNotebook *source,
+notebook_create_window_cb (GtkNotebook *source,
 			 GtkWidget   *page,
 			 gint         x,
 			 gint         y,
@@ -1893,8 +1919,6 @@ empathy_chat_window_class_init (EmpathyChatWindowClass *klass)
 		"  ythickness = 0\n"
 		"}\n"
 		"widget \"*.empathy-close-button\" style \"empathy-close-button-style\"");
-
-	gtk_notebook_set_window_creation_hook (chat_window_detach_hook, NULL, NULL);
 }
 
 static void
@@ -1964,7 +1988,12 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 	priv->chatroom_manager = empathy_chatroom_manager_dup_singleton (NULL);
 
 	priv->notebook = gtk_notebook_new ();
-	gtk_notebook_set_group (GTK_NOTEBOOK (priv->notebook), "EmpathyChatWindow");
+
+	g_signal_connect (priv->notebook, "create-window",
+		G_CALLBACK (notebook_create_window_cb), window);
+
+	gtk_notebook_set_group_name (GTK_NOTEBOOK (priv->notebook),
+		"EmpathyChatWindow");
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (priv->notebook), TRUE);
 	gtk_notebook_popup_enable (GTK_NOTEBOOK (priv->notebook));
 	gtk_box_pack_start (GTK_BOX (chat_vbox), priv->notebook, TRUE, TRUE, 0);
@@ -2071,17 +2100,23 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 						   window);
 }
 
-EmpathyChatWindow *
-empathy_chat_window_new (void)
+static GtkWidget *
+empathy_chat_window_get_dialog (EmpathyChatWindow *window)
 {
-	return EMPATHY_CHAT_WINDOW (g_object_new (EMPATHY_TYPE_CHAT_WINDOW, NULL));
+	EmpathyChatWindowPriv *priv;
+
+	g_return_val_if_fail (window != NULL, NULL);
+
+	priv = GET_PRIV (window);
+
+	return priv->dialog;
 }
 
 /* Returns the window to open a new tab in if there is only one window
  * visble, otherwise, returns NULL indicating that a new window should
  * be added.
  */
-EmpathyChatWindow *
+static EmpathyChatWindow *
 empathy_chat_window_get_default (gboolean room)
 {
 	GSettings *gsettings = g_settings_new (EMPATHY_PREFS_UI_SCHEMA);
@@ -2127,19 +2162,7 @@ empathy_chat_window_get_default (gboolean room)
 	return NULL;
 }
 
-GtkWidget *
-empathy_chat_window_get_dialog (EmpathyChatWindow *window)
-{
-	EmpathyChatWindowPriv *priv;
-
-	g_return_val_if_fail (window != NULL, NULL);
-
-	priv = GET_PRIV (window);
-
-	return priv->dialog;
-}
-
-void
+static void
 empathy_chat_window_add_chat (EmpathyChatWindow *window,
 			      EmpathyChat	*chat)
 {
@@ -2168,11 +2191,28 @@ empathy_chat_window_add_chat (EmpathyChatWindow *window,
 
 		g_object_unref (gsettings);
 
-		if (separate_windows) {
-			name = empathy_chat_get_id (chat);
-		}
-		else if (empathy_chat_is_room (chat)) {
+		if (empathy_chat_is_room (chat))
 			name = "room-window";
+
+		if (separate_windows) {
+			gint x, y;
+
+			/* Save current position of the window */
+			gtk_window_get_position (GTK_WINDOW (priv->dialog), &x, &y);
+
+			/* First bind to the 'generic' name. So new window for which we didn't
+			* save a geometry yet will have the geometry of the last saved
+			* window (bgo #601191). */
+			empathy_geometry_bind (GTK_WINDOW (priv->dialog), name);
+
+			/* Restore previous position of the window so the newly created window
+			* won't be in the same position as the latest saved window and so
+			* completely hide it. */
+			gtk_window_move (GTK_WINDOW (priv->dialog), x, y);
+
+			/* Then bind it to the name of the contact/room so we'll save the
+			* geometry specific to this window */
+			name = empathy_chat_get_id (chat);
 		}
 
 		empathy_geometry_bind (GTK_WINDOW (priv->dialog), name);
@@ -2208,7 +2248,7 @@ empathy_chat_window_add_chat (EmpathyChatWindow *window,
 	DEBUG ("Chat added (%d references)", G_OBJECT (chat)->ref_count);
 }
 
-void
+static void
 empathy_chat_window_remove_chat (EmpathyChatWindow *window,
 				 EmpathyChat	   *chat)
 {
@@ -2246,7 +2286,7 @@ empathy_chat_window_remove_chat (EmpathyChatWindow *window,
 	g_object_unref (chat);
 }
 
-void
+static void
 empathy_chat_window_move_chat (EmpathyChatWindow *old_window,
 			       EmpathyChatWindow *new_window,
 			       EmpathyChat       *chat)
@@ -2275,7 +2315,7 @@ empathy_chat_window_move_chat (EmpathyChatWindow *old_window,
 	g_object_unref (chat);
 }
 
-void
+static void
 empathy_chat_window_switch_to_chat (EmpathyChatWindow *window,
 				    EmpathyChat	      *chat)
 {
@@ -2293,21 +2333,6 @@ empathy_chat_window_switch_to_chat (EmpathyChatWindow *window,
 				       page_num);
 }
 
-gboolean
-empathy_chat_window_has_focus (EmpathyChatWindow *window)
-{
-	EmpathyChatWindowPriv *priv;
-	gboolean              has_focus;
-
-	g_return_val_if_fail (EMPATHY_IS_CHAT_WINDOW (window), FALSE);
-
-	priv = GET_PRIV (window);
-
-	g_object_get (priv->dialog, "has-toplevel-focus", &has_focus, NULL);
-
-	return has_focus;
-}
-
 EmpathyChat *
 empathy_chat_window_find_chat (TpAccount   *account,
 			       const gchar *id)
@@ -2389,7 +2414,7 @@ empathy_chat_window_present_chat (EmpathyChat *chat,
 	gtk_widget_grab_focus (chat->input_text_view);
 }
 
-void
+static void
 empathy_chat_window_get_nb_chats (EmpathyChatWindow *self,
 			       guint *nb_rooms,
 			       guint *nb_private)
