@@ -143,7 +143,6 @@ add_notification_actions (EmpathyStatusIcon *self,
 			break;
 
 		case EMPATHY_EVENT_TYPE_VOIP:
-		case EMPATHY_EVENT_TYPE_CALL:
 			notify_notification_add_action (notification,
 				"reject", _("Reject"), (NotifyActionCallback) notification_decline_cb,
 					self, NULL);
@@ -207,8 +206,8 @@ status_icon_update_notification (EmpathyStatusIcon *icon)
 			   to an existing notification with the same title.
 			   In this way the previous message will not be lost: the new
 			   message will appear below it, in the same notification */
-			notification = notify_notification_new
-				(priv->event->header, message_esc, NULL);
+			notification = notify_notification_new_with_status_icon
+				(priv->event->header, message_esc, NULL, priv->icon);
 
 			if (priv->notification == NULL) {
 				priv->notification = notification;
@@ -331,14 +330,10 @@ status_icon_event_added_cb (EmpathyEventManager *manager,
 		return;
 	}
 
-	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
-		return;
-	}
-
 	DEBUG ("New event %p", event);
 
 	priv->event = event;
-	if (event->must_ack || event->type == EMPATHY_EVENT_TYPE_AUTH) {
+	if (event->must_ack) {
 		priv->showing_event_icon = TRUE;
 		status_icon_update_icon (icon);
 		status_icon_update_tooltip (icon);
@@ -363,10 +358,6 @@ status_icon_event_removed_cb (EmpathyEventManager *manager,
 		return;
 	}
 
-	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
-		return;
-	}
-
 	priv->event = empathy_event_manager_get_top_event (priv->event_manager);
 
 	status_icon_update_tooltip (icon);
@@ -394,10 +385,6 @@ status_icon_event_updated_cb (EmpathyEventManager *manager,
 		return;
 	}
 
-	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
-		return;
-	}
-
 	if (empathy_notify_manager_notification_is_enabled (priv->notify_mgr)) {
 		status_icon_update_notification (icon);
 	}
@@ -479,7 +466,7 @@ status_icon_key_press_event_cb  (GtkWidget *window,
 				 GdkEventKey *event,
 				 EmpathyStatusIcon *icon)
 {
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		status_icon_set_visibility (icon, FALSE, TRUE);
 	}
 	return FALSE;
